@@ -52,6 +52,7 @@ class FluxAgent:
         whitelisted_addresses: list = ["127.0.0.1"],
         verify_source_address: bool = True,
         signed_vault_connections: bool = False,
+        zelid: str = "",
     ):
         self.app = web.Application()
         self.enable_local_fileserver = enable_local_fileserver
@@ -81,7 +82,11 @@ class FluxAgent:
 
         auth_provider = None
         if signed_vault_connections:
-            address = self.loop.run_until_complete(self.get_app_owner_zelid())
+            # this is solely for testing without an app
+            if zelid:
+                address = zelid
+            else:
+                address = self.loop.run_until_complete(self.get_app_owner_zelid())
             self.log.info(f"App zelid is: {address}")
             auth_provider = SignatureAuthProvider(address=address)
 
@@ -104,7 +109,6 @@ class FluxAgent:
                 # print(resp.status)
                 data = await resp.json()
                 zelid = data.get("data", "")
-        zelid = "1GKugrE8cmw9NysWFJPwszBbETRLwLaLmM"
         return zelid
 
     def get_logger(self) -> logging.Logger:
